@@ -32,6 +32,8 @@ from labelbox.schema.user import User
 from labelbox.schema.project import Project
 from labelbox.schema.role import Role
 
+from labelbox.schema.media_type import MediaType
+
 logger = logging.getLogger(__name__)
 
 _LABELBOX_API_KEY = "LABELBOX_API_KEY"
@@ -88,6 +90,7 @@ class Client:
             'Authorization': 'Bearer %s' % api_key,
             'X-User-Agent': f'python-sdk {SDK_VERSION}'
         }
+        self._data_row_metadata_ontology = None
 
     @retry.Retry(predicate=retry.if_exception_type(
         labelbox.exceptions.InternalServerError))
@@ -611,6 +614,15 @@ class Client:
             InvalidAttributeError: If the Project type does not contain
                 any of the attribute names given in kwargs.
         """
+        media_type = kwargs.get("media_type")
+        if media_type:
+            if MediaType.is_supported(media_type):
+                kwargs["media_type"] = media_type.value
+            else:
+                raise TypeError(f"{media_type} is not a valid media type. Use"
+                                f" any of {MediaType.get_supported_members()}"
+                                " from MediaType. Example: MediaType.Image.")
+
         return self._create(Entity.Project, kwargs)
 
     def get_roles(self) -> List[Role]:
@@ -637,7 +649,9 @@ class Client:
             DataRowMetadataOntology: The ontology for Data Row Metadata for an organization
 
         """
-        return DataRowMetadataOntology(self)
+        if self._data_row_metadata_ontology is None:
+            self._data_row_metadata_ontology = DataRowMetadataOntology(self)
+        return self._data_row_metadata_ontology
 
     def get_model(self, model_id) -> Model:
         """ Gets a single Model with the given ID.
