@@ -1,4 +1,5 @@
 from typing import Any, Dict, List, Union, Optional
+import warnings
 
 try:
     from typing import Literal
@@ -72,6 +73,15 @@ class Dropdown(_TempName):
     """
     - A classification with many selected options allowed .
     - This is not currently compatible with MAL.
+
+    Deprecation Notice: Dropdown classification is deprecated and will be
+        removed in a future release. Dropdown will also
+        no longer be able to be created in the Editor on 3/31/2022.    
     """
     name: Literal["dropdown"] = "dropdown"
     answer: List[ClassificationAnswer]
+
+    def __init__(self, **data: Any):
+        warnings.warn("Dropdown classification is deprecated and will be "
+                      "removed in a future release")
+        super().__init__(**data)
\ No newline at end of file
