@@ -71,6 +71,12 @@ class InvalidQueryError(LabelboxError):
     pass
 
 
+class ResourceCreationError(LabelboxError):
+    """ Indicates that a resource could not be created in the server side
+    due to a validation or transaction error"""
+    pass
+
+
 class NetworkError(LabelboxError):
     """Raised when an HTTPError occurs."""
 
@@ -122,4 +128,4 @@ class MALValidationError(LabelboxError):
 
 class OperationNotAllowedException(Exception):
     """Raised when user does not have permissions to a resource or has exceeded usage limit"""
-    pass
\ No newline at end of file
+    pass
