@@ -1,6 +1,5 @@
 # type: ignore
 from datetime import datetime
-import warnings
 from copy import deepcopy
 from enum import Enum
 from itertools import chain
@@ -200,6 +199,10 @@ class DataRowMetadataOntology:
 
         return fields
 
+    def refresh_ontology(self):
+        self._raw_ontology = self._get_ontology()
+        self._build_ontology()
+
     def parse_metadata(
         self, unparsed: List[Dict[str,
                                   List[Union[str,
@@ -220,26 +223,53 @@ class DataRowMetadataOntology:
 
         for dr in unparsed:
             fields = []
-            for f in dr["fields"]:
-                schema = self.fields_by_id[f["schemaId"]]
-                if schema.kind == DataRowMetadataKind.enum:
-                    continue
-                elif schema.kind == DataRowMetadataKind.option:
-                    field = DataRowMetadataField(schema_id=schema.parent,
-                                                 value=schema.uid)
-                elif schema.kind == DataRowMetadataKind.datetime:
-                    field = DataRowMetadataField(
-                        schema_id=schema.uid,
-                        value=datetime.fromisoformat(f["value"][:-1] +
-                                                     "+00:00"))
-                else:
-                    field = DataRowMetadataField(schema_id=schema.uid,
-                                                 value=f["value"])
-                fields.append(field)
+            if "fields" in dr:
+                fields = self.parse_metadata_fields(dr["fields"])
             parsed.append(
                 DataRowMetadata(data_row_id=dr["dataRowId"], fields=fields))
         return parsed
 
+    def parse_metadata_fields(
+            self, unparsed: List[Dict[str,
+                                      Dict]]) -> List[DataRowMetadataField]:
+        """ Parse metadata fields as list of `DataRowMetadataField`
+
+        >>> mdo.parse_metadata_fields([metadata_fields])
+
+        Args:
+            unparsed: An unparsed list of metadata represented as a dict containing 'schemaId' and 'value'
+
+        Returns:
+            metadata: List of `DataRowMetadataField`
+        """
+        parsed = []
+        if isinstance(unparsed, dict):
+            raise ValueError("Pass a list of dictionaries")
+
+        for f in unparsed:
+            if f["schemaId"] not in self.fields_by_id:
+                # Update metadata ontology if field can't be found
+                self.refresh_ontology()
+                if f["schemaId"] not in self.fields_by_id:
+                    raise ValueError(
+                        f"Schema Id `{f['schemaId']}` not found in ontology")
+
+            schema = self.fields_by_id[f["schemaId"]]
+            if schema.kind == DataRowMetadataKind.enum:
+                continue
+            elif schema.kind == DataRowMetadataKind.option:
+                field = DataRowMetadataField(schema_id=schema.parent,
+                                             value=schema.uid)
+            elif schema.kind == DataRowMetadataKind.datetime:
+                field = DataRowMetadataField(
+                    schema_id=schema.uid,
+                    value=datetime.fromisoformat(f["value"][:-1] + "+00:00"))
+            else:
+                field = DataRowMetadataField(schema_id=schema.uid,
+                                             value=f["value"])
+            parsed.append(field)
+        return parsed
+
     def bulk_upsert(
             self, metadata: List[DataRowMetadata]
     ) -> List[DataRowMetadataBatchResponse]:
@@ -297,7 +327,6 @@ class DataRowMetadataOntology:
                         chain.from_iterable(
                             self._parse_upsert(m) for m in m.fields))).dict(
                                 by_alias=True))
-
         res = _batch_operations(_batch_upsert, items, self._batch_size)
         return res
 
@@ -399,8 +428,11 @@ class DataRowMetadataOntology:
         """Format for metadata upserts to GQL"""
 
         if metadatum.schema_id not in self.fields_by_id:
-            raise ValueError(
-                f"Schema Id `{metadatum.schema_id}` not found in ontology")
+            # Update metadata ontology if field can't be found
+            self.refresh_ontology()
+            if metadatum.schema_id not in self.fields_by_id:
+                raise ValueError(
+                    f"Schema Id `{metadatum.schema_id}` not found in ontology")
 
         schema = self.fields_by_id[metadatum.schema_id]
 
@@ -421,6 +453,33 @@ class DataRowMetadataOntology:
 
         return [_UpsertDataRowMetadataInput(**p) for p in parsed]
 
+    # Convert metadata to DataRowMetadataField objects, parse all fields
+    # and return a dictionary of metadata fields for upsert
+    def parse_upsert_metadata(self, metadata_fields):
+
+        def _convert_metadata_field(metadata_field):
+            if isinstance(metadata_field, DataRowMetadataField):
+                return metadata_field
+            elif isinstance(metadata_field, dict):
+                if not all(key in metadata_field
+                           for key in ("schema_id", "value")):
+                    raise ValueError(
+                        f"Custom metadata field '{metadata_field}' must have 'schema_id' and 'value' keys"
+                    )
+                return DataRowMetadataField(
+                    schema_id=metadata_field["schema_id"],
+                    value=metadata_field["value"])
+            else:
+                raise ValueError(
+                    f"Metadata field '{metadata_field}' is neither 'DataRowMetadataField' type or a dictionary"
+                )
+
+        # Convert all metadata fields to DataRowMetadataField type
+        metadata_fields = [_convert_metadata_field(m) for m in metadata_fields]
+        parsed_metadata = list(
+            chain.from_iterable(self._parse_upsert(m) for m in metadata_fields))
+        return [m.dict(by_alias=True) for m in parsed_metadata]
+
     def _validate_delete(self, delete: DeleteDataRowMetadata):
         if not len(delete.fields):
             raise ValueError(f"No fields specified for {delete.data_row_id}")
@@ -428,8 +487,11 @@ class DataRowMetadataOntology:
         deletes = set()
         for schema_id in delete.fields:
             if schema_id not in self.fields_by_id:
-                raise ValueError(
-                    f"Schema Id `{schema_id}` not found in ontology")
+                # Update metadata ontology if field can't be found
+                self.refresh_ontology()
+                if schema_id not in self.fields_by_id:
+                    raise ValueError(
+                        f"Schema Id `{schema_id}` not found in ontology")
 
             schema = self.fields_by_id[schema_id]
             # handle users specifying enums by adding all option enums
