@@ -1,12 +1,11 @@
 from dataclasses import dataclass
 from typing import Dict, Optional, TYPE_CHECKING
 
-from labelbox.orm.model import Field
+from labelbox.orm.model import Field, Entity
 from labelbox.orm.db_object import DbObject
-from labelbox.schema.project import Project
 
 if TYPE_CHECKING:
-    from labelbox import Client
+    from labelbox import Client, Project
 
 _ROLES: Optional[Dict[str, "Role"]] = None
 
@@ -41,5 +40,5 @@ class UserRole(Role):
 
 @dataclass
 class ProjectRole:
-    project: Project
+    project: "Project"
     role: Role
